@@ -727,7 +727,7 @@ TestDirOps(int directory_size, int max_size, int min_size
   // then the storage of file names will take more than half RAM and there
   // won't be enough RAM to have Bonnie++ paged in and to have a reasonable
   // meta-data cache.
-  if(globals.ram && directory_size * MaxDataPerFile * 2 > (globals.ram << 10))
+  if(globals.ram && directory_size * MaxDataPerFile * 2 > int((globals.ram << 10)))
   {
     fprintf(stderr
         , "When testing %dK of files in %d MiB of RAM the system is likely to\n"
